from .config import get_cacheversion
from ..models import CacheVersion
from common.models import Category
from django.utils.html import format_html, format_html_join
from django.db.models import QuerySet
from django.urls import reverse

class CacheCategory(object):
    """docstring for CacheCategory."""

    def __init__(self):
        self._data_version = 0
        self._category: dict = None
        self._category_html: dict = None
        self._category_order: dict = None
        self._order_select=None
        self._category_root:dict=None
    @property
    def categories(self):
        """
        Purpose:
        """
        cacheversion = get_cacheversion()
        version_last = cacheversion[CacheVersion.VerName.Category].version
        if version_last > self._data_version or self._category is None:
            self.update_data()
            self._data_version = version_last
        return {"category": self._category, "category_html": self._category_html, "category_order": self._category_order,'category_root':self._category_root}

    def update_data(self):
        """
        Purpose:
        """
        if self._category is not None:
            self._category.clear()
        self._category = {}
        if self._category_html is not None:
            self._category_html.clear()
        self._category_html = {}
        if self._category_order is not None:
            self._category_order.clear()
        self._category_order = {}
        self._order_select=0
        if self._category_root is not None:
            self._category_root.clear()
        
        for usage in Category.Usage.choices:
            qa = Category.objects.filter(usage=usage[0], parent=None)
            obj = {"usage": usage, "data": qa}
            self._category[usage[0]] = obj
            self._category_html[usage[0]] = {
                "usage": usage,
                "html": self.build_html(qa),
            }
            self._category_order[usage[0]] = {
                "usage": usage,
                "data": Category.objects.filter(usage=usage[0]).order_by('order_select')
            }
        self._category_order['all'] = Category.objects.order_by('order_select')
        self._category_root=self.build_category_root()
        pass
    def build_category_root(self):
        res={}
        for usage in Category.Usage.choices:
            res[usage[0]]=Category.objects.get(parent=None,usage=usage[0])
            pass
        return res
    def build_html(self, qa: QuerySet):
        """
        Purpose:
        """
        html = [
            "<ul>",
        ]
        for category in qa:
            self._order_select+=1
            category.order_select=self._order_select
            category.layer_select=1
            category.save()
            html_li = "".join(self.build_category_html([], category))
            html.append(html_li)

        html.append("</ul>")
        return format_html("".join(html))

    def build_category_html(self, res: list, category: Category):
        """
        Purpose:
        """
        url_publish=''
        # url_add=f"/adm/category/edit/?preid={category.id}"
        url_add="%s?preid=%s"%(reverse("adm:category-create"),category.id)
        # url_edit=f"/adm/category/edit/{category.id}"
        url_edit=reverse("adm:category-edit",args=(category.id,))
        url_delete=''
        html_li2=f"<li><p class='d-flex border-bottom'><span class='flex-grow-1'>{category.name}#{category.usage}#{category.layer_select}#{category.order_select}</span><span><a href='{url_edit}'>编辑</a> <a href='{url_add}'>添加子栏目</a> <a href='{url_publish}'>发布</a> <a href='{url_delete}'>删除</a></span></p>"
        if not res:
            res = [
                html_li2,
            ]
        else:
            res.append(html_li2)
        if category.category_set.exists():
            res.append("<ul>")
            for cat in category.category_set.all():
                self._order_select+=1
                cat.order_select=self._order_select
                cat.layer_select=category.layer_select+1
                cat.save()
                self.build_category_html(res, cat)
              
            res.append("</ul>")
        res.append("</li>")
        return res


cache_category = CacheCategory()
