from django import forms
from common.models import ArticleSummary,ArticleContent
from django.core.paginator import Paginator,Page
from common.forms import ToppingSelect
from common.models import Category
from ..caches import cache_category
class ArticleIndexForm(forms.Form):
    """CategoryIndexForm definition."""
    catid=forms.ModelChoiceField(queryset=None,
                                  label="所属栏目",help_text="请选择栏目",required=False,widget=ToppingSelect(attrs={'class':'form-select'}),empty_label=None)
    status = forms.ChoiceField(choices=ArticleSummary.Status.choices,widget=forms.Select(attrs={'class':'form-select'}))
    keywords=forms.CharField(max_length=25,required=False,widget=forms.TextInput(attrs={'class':'form-control','placeholder':'请输入搜索关键字'}))
    order = forms.CharField(max_length=25,required=False)
    
    # page = forms.IntegerField()
    def search(self)->Paginator:
        qa=ArticleSummary.objects.all()
        catid= 0 if 'catid' not in self.cleaned_data or  self.cleaned_data['catid'] is None else self.cleaned_data['catid'].pk
        status=int(self.cleaned_data['status'])
        keywords= str(self.cleaned_data['keywords']).strip() or None
        qa=qa.order_by(self.cleaned_data['order'])
        if catid>0:
            preid=f",{catid},"
            qa=qa.filter(category__preid__contains=preid)
        if status>0:
            qa=qa.filter(status=status)
        if keywords:
            qa=qa.filter(title__contains=keywords)
        paginator=Paginator(qa,3)
        return paginator
    
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs) 
        self.fields['catid'].queryset=cache_category.categories['category_order'][Category.Usage.Article]["data"]
        if self.data['catid']==0:
            self.data['catid']=cache_category.categories['category_root'][Category.Usage.Article].pk
        pass
    

class ArticleSummaryForm(forms.ModelForm):
    category=forms.ModelChoiceField(queryset=None,
                                  label="所属栏目",help_text="请选择栏目",required=False,widget=ToppingSelect(attrs={'class':'form-select'}),empty_label=None)
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs) 
        self.fields['category'].queryset=cache_category.categories['category_order'][Category.Usage.Article]["data"]
    class Meta:
        model = ArticleSummary
        fields = ['title','keywords','description','category',]
        pass
class ArticleContentForm(forms.ModelForm):
    """Form definition for ArticleContent."""

    class Meta:
        """Meta definition for ArticleContentform."""
        model = ArticleContent
        fields = ('content',)
