from django.http import HttpRequest
from django.shortcuts import render
from django.views import View
from django.core.paginator import Paginator
from ..forms.article import ArticleIndexForm,ArticleSummaryForm,ArticleContentForm
from common.models import ArticleSummary,ArticleContent
from django.urls import reverse
from django.http import QueryDict
from django.db import transaction
class ArticleIndexView(View):
    def get(self, request: HttpRequest,catid=0,status=0,order='-id'):
        page=int(request.GET.get('page',1))
        catid=request.GET.get('catid',catid)
        status=request.GET.get('status',status)
        keywords=request.GET.get('keywords','')
        order=request.GET.get('order',order)
        data={"catid":catid,"status":status,'keywords':keywords,'page':page,'order':order}
        form = ArticleIndexForm(data)
        if form.is_valid():
            paginator=form.search()
            page_obj=paginator.get_page(page)
            page_range=paginator.get_elided_page_range(page)
            query=QueryDict(mutable=True)
            query.update(data)
            query.pop('page')
            query_url=query.urlencode()
            page_url=f"{reverse('adm:article-index')}?{query_url}"
            return render(request,'adm/article-index.html',{'form':form,"page_obj":page_obj,"page_range":page_range,'page':page,'page_url':page_url})
        return render(request,'adm/article-index.html',{'form':form,})

    def post(self,request: HttpRequest,id=0):
        form = ArticleIndexForm(request.POST)

class ArticleEditView(View):
    def get_forminfo(self, id=0,instance=None):
        url=None
        title=None
        if instance is not None:
            url=reverse("adm:article-edit",args=(instance.id,))
            title=f"编辑文档#{instance.id}"
        elif id>0:
            url=reverse("adm:article-edit",args=(id,))
            title=f"编辑文档#{id}"
        else:
            url=reverse("adm:article-create")
            title="新建文档"
        return {"url":url,"title":title}
    def get(self,request: HttpRequest,id=0):
        if id>0:
            summary=ArticleSummary.objects.get(id=id)
            content=summary.content
            form_summary=ArticleSummaryForm(instance=summary)
            form_content=ArticleContentForm(instance=content)
        else:
            form_summary=ArticleSummaryForm()
            form_content=ArticleContentForm()   
        return render(request,'adm/article-edit.html',{'forminfo':self.get_forminfo(id),"form_summary":form_summary,"form_content":form_content})
        pass
    def post(self, request: HttpRequest,id=0):
        msg='success!'
        if id>0:
            summary=ArticleSummary.objects.get(id=id)
            content=summary.content   
            form_summary=ArticleSummaryForm(data=request.POST,instance=summary)
            form_content=ArticleContentForm(data=request.POST,instance=content)                     
            if form_summary.is_valid() and form_content.is_valid():
                try:
                    with transaction.atomic():
                        form_summary.save()
                        form_content.save()  
                except Exception as e:
                    msg='error!'
            else:
                 msg='error!'            
                
            return render(request,'adm/article-edit.html',{'forminfo':self.get_forminfo(id,summary),"form_summary":form_summary,"form_content":form_content,'msg':msg})
        else:
            form_summary=ArticleSummaryForm(data=request.POST)
            form_content=ArticleContentForm(data=request.POST)
            if form_summary.is_valid() and form_content.is_valid():
                try:
                    with transaction.atomic():
                        summary=form_summary.save()
                        obj=form_content.save(False)  
                        obj.summary=summary
                        obj.save() 
                except Exception as e:
                    msg='error!'
                       
                return render(request,'adm/article-edit.html',{'forminfo':self.get_forminfo(id,summary),"form_summary":form_summary,"form_content":form_content,'msg':msg})
            else:
                msg='error!'
                return render(request,'adm/article-edit.html',{'forminfo':self.get_forminfo(id),"form_summary":form_summary,"form_content":form_content,'msg':msg})

        pass


    
class ArticleDeleteView(View):
    
    def get(self, request: HttpRequest):
        pass