from django.http import HttpRequest
from django.shortcuts import render,redirect
from django.urls import reverse
from django.views import View
from common.models import Category
from django.utils.html import format_html
from ..models import CacheVersion
from ..caches import cache_category
from ..forms.category import CategoryEditForm
class CategoryIndexView(View):
    def get(self, request: HttpRequest):
        categories = cache_category.categories
        return render(request,'adm/category-index.html',{"categories":categories,})

class CategoryEditView(View):
    # def setup(self,request, *args, **kwargs):
    #     super().setup(request, *args, **kwargs)
    #     if 'id' in kwargs:
    #         self.url=reverse("adm:category-edit",args=(kwargs['id'],))
    #     else:
    #         self.url=reverse("adm:category-create")
    def get_forminfo(self, id=0,instance:Category=None):
        url=None
        title=None
        if instance is not None:
            url=reverse("adm:category-edit",args=(instance.id,))
            title=f"编辑栏目#{instance.id}"
        elif id>0:
            url=reverse("adm:category-edit",args=(id,))
            title=f"编辑栏目#{id}"
        else:
            url=reverse("adm:category-create")
            title="新建栏目"
        return {"url":url,"title":title}
        
    def get(self, request: HttpRequest,id=0):
        if id>0:
            form = CategoryEditForm(instance=Category.objects.get(id=id))
        else:
            if 'preid' in request.GET:
                form = CategoryEditForm(initial={'parent':request.GET['preid']})
            else:
                form=CategoryEditForm()
        return render(request,'adm/category-edit.html',{'forminfo':self.get_forminfo(id),"form":form})
    def post(self, request: HttpRequest,id=0):
        """_summary_

        Args:
            request (HttpRequest): _description_
            id (int, optional): _description_. Defaults to 0.

        Returns:
            _type_: _description_
        """
        msg="error!"
        if id>0:
            instance=Category.objects.get(id=id)
            form = CategoryEditForm(data=request.POST,instance=instance)
            if form.is_valid():
                form.save()
                msg='success!'
            return render(request,'adm/category-edit.html',{'forminfo':self.get_forminfo(id,instance),"form":form,'msg':msg})
        else:
            form=CategoryEditForm(data=request.POST)
            if form.is_valid():
                obj:Category=form.save()
                CacheVersion.increase_category_version()
                cache_category.update_data()
                form = CategoryEditForm(instance=obj)
                msg='success!'
                return render(request,'adm/category-edit.html',{'forminfo':self.get_forminfo(id,obj),"form":form,'msg':msg})
            else:
                return render(request,'adm/category-edit.html',{'forminfo':self.get_forminfo(id),"form":form,'msg':msg})
                # return redirect(reverse("adm:category-edit",args=(obj.id,)))
            

    
class CategoryDeleteView(View):
    
    def get(self, request: HttpRequest):
        pass
    
