from django.utils import timezone
from django.db import models
from .category import Category
from .tag import Tag
from django.urls import reverse
# Create your models here.
class ArticleSummary(models.Model):
    """Model definition for Summary."""
    class Status(models.IntegerChoices):
        """docstring for Status."""
        All=0,"所有状态"
        Unfinished=1,"编辑中"
        PendingCheck=2,"待审核"
        Refused=3,"审核失败"
        Passed=4,"审核成功"
        Discarded=5,"被丢弃"
        
    # TODO: Define fields here
    title = models.CharField(max_length = 150)
    keywords = models.CharField(max_length = 150,blank=True)
    description = models.CharField(max_length = 150,blank=True)
    category = models.ForeignKey(Category, on_delete=models.CASCADE)
    #跑马灯，置顶，热点，缩略图
    tags = models.ManyToManyField(Tag)
    create_at = models.DateTimeField(default=timezone.now())
    update_at = models.DateTimeField(default=timezone.now())
    status = models.IntegerField(choices=Status.choices,default=Status.Unfinished)
    
    class Meta:
        """Meta definition for Summary."""

        verbose_name = 'Summary'
        verbose_name_plural = 'Summarys'

    def __str__(self):
        """Unicode representation of Summary."""
        return f"文档#{self.id}#{self.title}"
    
    def get_edit_url(self):
        return reverse('adm:article-edit',args=(self.id,))
    def get_absolute_url(self):
        """Return absolute url for Summary."""
        return ('')

    # TODO: Define custom methods here
class ArticleContent(models.Model):
    """Model definition for Content."""

    # TODO: Define fields here
    summary = models.OneToOneField(ArticleSummary, on_delete=models.CASCADE,related_name='content')
    content = models.TextField()
    
    class Meta:
        """Meta definition for Content."""

        verbose_name = 'Content'
        verbose_name_plural = 'Contents'

    def __str__(self):
        """Unicode representation of Content."""
        return f"文档内容#{self.summary.id}#{self.summary.title}"
    
# class ArticleExtend(models.Model):
#     """Model definition for Additions."""

#     # TODO: Define fields here
#     summary = models.OneToOneField(ArticleSummary, on_delete=models.CASCADE)
#     charfield1 = models.CharField()
#     charfield2 = models.CharField()
#     charfield3 = models.CharField()
#     charfield4 = models.CharField()
#     charfield5 = models.CharField()
#     integerfield1 = models.IntegerField()
#     integerfield2 = models.IntegerField()
#     integerfield3 = models.IntegerField()
#     decimalfield1 = models.DecimalField()
#     decimalfield2 = models.DecimalField()
#     decimalfield3 = models.DecimalField()
#     textfield1 = models.TextField()
#     textfield2 = models.TextField()
#     textfield3 = models.TextField()
    
#     class Meta:
#         """Meta definition for Additions."""

#         verbose_name = 'Additions'
#         verbose_name_plural = 'Additionss'

#     def __str__(self):
#         """Unicode representation of Additions."""
#         pass
    
# class AdditionTemplate(models.Model):
#     """Model definition for AdditionTemplate."""
#     summary = models.OneToOneField(Summary, on_delete=models.CASCADE)
#     name = models.CharField(max_length = 150)
#     description = models.CharField(max_length = 255)
#     # TODO: Define fields here

#     class Meta:
#         """Meta definition for AdditionTemplate."""

#         verbose_name = 'AdditionTemplate'
#         verbose_name_plural = 'AdditionTemplates'

#     def __str__(self):
#         """Unicode representation of AdditionTemplate."""
#         pass

# class AdditionFieldUsed(models.Model):
#     """Model definition for AdditionsInfo."""
#     class Usage(models.TextChoices):
#         Image='image','图片'
#         text='text','文本'
#         html='html','超文本'
#         boolean='boolean','布尔'
#     template = models.ForeignKey(AdditionTemplate, on_delete=models.CASCADE)
#     fieldName = models.CharField(max_length = 150)
#     usage = models.CharField(max_length = 150,choices=Usage.choices)
#     verbose_name = models.CharField(max_length = 150)
#     verbose_name_plural = models.CharField(max_length = 150)
#     # TODO: Define fields here

#     class Meta:
#         """Meta definition for AdditionsInfo."""

#         verbose_name = 'AdditionsInfo'
#         verbose_name_plural = 'AdditionsInfos'

#     def __str__(self):
#         """Unicode representation of AdditionsInfo."""
#         pass

# class Additions(models.Model):
#     """Model definition for Additions."""

#     # TODO: Define fields here
#     summary = models.OneToOneField(Summary, on_delete=models.CASCADE)
#     charfield1 = models.CharField()
#     charfield2 = models.CharField()
#     charfield3 = models.CharField()
#     charfield4 = models.CharField()
#     charfield5 = models.CharField()
#     charfield6 = models.CharField()
#     models.DecimalField()
#     textfield1 = models.TextField()
    
#     class Meta:
#         """Meta definition for Additions."""

#         verbose_name = 'Additions'
#         verbose_name_plural = 'Additionss'

#     def __str__(self):
#         """Unicode representation of Additions."""
#         pass
    
    
    
    
    

# class ArticleNews(models.Model):
#     """Model definition for ArticleNews."""

#     # TODO: Define fields here
#     content = models.TextField()
#     summary = models.OneToOneField(Summary, on_delete=models.CASCADE)
    
#     class Meta:
#         """Meta definition for ArticleNews."""

#         verbose_name = 'ArticleNews'
#         verbose_name_plural = 'ArticleNewss'

#     def __str__(self):
#         """Unicode representation of ArticleNews."""
#         pass

#     def save(self):
#         """Save method for ArticleNews."""
#         pass

#     def get_absolute_url(self):
#         """Return absolute url for ArticleNews."""
#         return ('')

#     # TODO: Define custom methods here

# class ArticleImages(models.Model):
#     """Model definition for ArticleImages."""

#     # TODO: Define fields here
#     images = models.TextField()

#     class Meta:
#         """Meta definition for ArticleImages."""

#         verbose_name = 'ArticleImages'
#         verbose_name_plural = 'ArticleImagess'

#     def __str__(self):
#         """Unicode representation of ArticleImages."""
#         pass

#     def save(self):
#         """Save method for ArticleImages."""
#         pass

#     def get_absolute_url(self):
#         """Return absolute url for ArticleImages."""
#         return ('')

#     # TODO: Define custom methods here
